@@ -197,8 +197,6 @@ config_check_vuurmuurdir(const int debuglvl, const char *logdir)
 int
 check_iptables_command(const int debuglvl, struct vuurmuur_config *cnf, char *iptables_location, char quiet)
 {
-    char    cmd[sizeof(conf.iptables_location) + 32] = "";
-
     /* safety */
     if(cnf == NULL || iptables_location == NULL)
     {
@@ -217,9 +215,9 @@ check_iptables_command(const int debuglvl, struct vuurmuur_config *cnf, char *ip
     else
     {
         /* now check the command */
-        snprintf(cmd, sizeof(cmd), "%s --version &> /dev/null", iptables_location);
-
-        if(pipe_command(debuglvl, cnf, cmd, PIPE_QUIET) < 0)
+        char *args[] = { iptables_location, "--version", NULL };
+        int r = libvuurmuur_exec_command(debuglvl, cnf, iptables_location, args);
+        if (r != 0)
         {
             if(quiet == FALSE)
                 (void)vrprint.error(0, "Error", "The path '%s' to the 'iptables'-command seems to be wrong.", iptables_location);
@@ -237,8 +235,6 @@ check_iptables_command(const int debuglvl, struct vuurmuur_config *cnf, char *ip
 int
 check_iptablesrestore_command(const int debuglvl, struct vuurmuur_config *cnf, char *iptablesrestore_location, char quiet)
 {
-    char    cmd[sizeof(conf.iptablesrestore_location) + 32] = "";
-
     /* safety */
     if(cnf == NULL || iptablesrestore_location == NULL)
     {
@@ -257,9 +253,9 @@ check_iptablesrestore_command(const int debuglvl, struct vuurmuur_config *cnf, c
     else
     {
         /* now check the command */
-        snprintf(cmd, sizeof(cmd), "%s < /dev/null &> /dev/null", iptablesrestore_location);
-
-        if(pipe_command(debuglvl, cnf, cmd, PIPE_QUIET) < 0)
+        char *args[] = { iptablesrestore_location, "-h", NULL };
+        int r = libvuurmuur_exec_command(debuglvl, cnf, iptablesrestore_location, args);
+        if (r != 1)
         {
             if(quiet == FALSE)
                 (void)vrprint.error(0, "Error", "The path '%s' to the 'iptables-restore'-command seems to be wrong.", iptablesrestore_location);
@@ -271,6 +267,42 @@ check_iptablesrestore_command(const int debuglvl, struct vuurmuur_config *cnf, c
     return(1);
 }
 
+/*
+*/
+int
+check_tc_command(const int debuglvl, struct vuurmuur_config *cnf, char *tc_location, char quiet)
+{
+    /* safety */
+    if(cnf == NULL || tc_location == NULL)
+    {
+        (void)vrprint.error(-1, "Internal Error", "parameter problem (in: %s:%d).", __FUNC__, __LINE__);
+        return(-1);
+    }
+
+    /* first check if there even is a value */
+    if(strcmp(tc_location, "") == 0)
+    {
+        if(quiet == FALSE)
+            (void)vrprint.error(0, "Error", "The path to the 'tc'-command was not set.", tc_location);
+
+        return(0);
+    }
+    else
+    {
+        char *args[] = { tc_location, "-V", NULL };
+        int r = libvuurmuur_exec_command(debuglvl, cnf, tc_location, args);
+        if (r != 0)
+        {
+            if(quiet == FALSE)
+                (void)vrprint.error(0, "Error", "The path '%s' to the 'tc'-command seems to be wrong.", tc_location);
+
+            return(0);
+        }
+    }
+
+    return(1);
+}
+
 
 /* updates the logdirlocations in the cnf struct based on cnf->vuurmuur_log_dir */
 int
