@@ -18,6 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
+#include <sys/wait.h>
 #include "vuurmuur.h"
 
 
@@ -564,7 +565,8 @@ pipe_command(const int debuglvl, struct vuurmuur_config *cnf, char *command,
     if(debuglvl >= MEDIUM)
         (void)vrprint.debug(__FUNC__, "pipe opened succesfully.");
 
-    if(pclose(p))
+    int r = pclose(p);
+    if(r != 0)
     {
         if(!ignore_error)
         {
@@ -583,6 +585,60 @@ pipe_command(const int debuglvl, struct vuurmuur_config *cnf, char *command,
     return(retval);
 }
 
+/* libvuurmuur_exec_command
+ *
+ * Execute a system command. This functions blocks.
+ *
+ * Returns: -1 if the command failed to start (ie not found)
+ *          otherwise the return code of the command.
+ */
+int
+libvuurmuur_exec_command(const int debuglvl, struct vuurmuur_config *cnf, char *path, char *argv[])
+{
+    int retval = 0;
+    char *s = *argv;
+
+    if (debuglvl >= MEDIUM)
+        (void)vrprint.debug(__FUNC__, "starting, path %s", path);
+
+    pid_t pid = fork();
+    if (pid == 0) {
+        if (debuglvl >= MEDIUM)
+            (void)vrprint.debug(__FUNC__, "(child) started");
+
+        /* close stdout so we don't see the output of the
+         * command we execute */
+        fclose(stdout);
+
+        /* actually exec the command */
+        execv(path,argv);
+
+        /* if we get here, the command didn't exec
+         * so kill the child */
+        exit(127);
+    }
+    if (debuglvl >= MEDIUM)
+        (void)vrprint.debug(__FUNC__, "child pid is %u", pid);
+
+    int status;
+    pid_t rpid;
+    do {
+        rpid = waitpid(pid, &status, 0);
+    } while (rpid == -1 && errno == EINTR);
+
+    if (pid != -1 && WIFEXITED(status) && WEXITSTATUS(status)) {
+        if (debuglvl >= MEDIUM)
+            (void)vrprint.debug(__FUNC__, "WEXITSTATUS(status) %d", WEXITSTATUS(status));
+        retval = WEXITSTATUS(status);
+    }
+    else if (rpid == -1)
+        retval = -1;
+
+    if (debuglvl >= MEDIUM)
+        (void)vrprint.debug(__FUNC__, "retval %d", retval);
+    return retval;
+}
+
 
 void
 shm_update_progress(const int debuglvl, int semid, int *shm_progress, int set_percent)
