@@ -49,7 +49,7 @@
 #define __FUNC__        (char *)__FUNCTION__
 
 /* our version */
-#define LIBVUURMUUR_VERSION	"0.6"
+#define LIBVUURMUUR_VERSION	"0.7"
 
 /* we need this to stringify the VUURMUUR_CONFIGDIR which is supplied at compiletime see:
    http://gcc.gnu.org/onlinedocs/gcc-3.4.1/cpp/Stringification.html#Stringification */
@@ -708,6 +708,9 @@ typedef struct InterfaceData_
     u_int32_t       total_shape_rules;
     u_int32_t       total_default_shape_rules;
 
+    /* tcpmss clamping */
+    char            tcpmss_clamp;
+
 } InterfaceData;
 
 
@@ -1021,6 +1024,8 @@ typedef struct
     char    target_connmark;
     char    proc_net_netfilter_nfnetlink_queue;
 
+    char    target_tcpmss;
+
     /* matches */
     char    match_tcp;
     char    match_udp;
@@ -1034,6 +1039,7 @@ typedef struct
     char    match_mac;
     char    match_connmark;
 
+    char    target_nat_random;
 } IptCap;
 
 
@@ -1404,6 +1410,7 @@ int remove_pidfile(char *pidfile_location);
 FILE * rules_file_open(const char *path, const char *mode, int caller);
 int rules_file_close(FILE *file, const char *path);
 int pipe_command(const int, struct vuurmuur_config *, char *, char);
+int libvuurmuur_exec_command(const int, struct vuurmuur_config *, char *, char **);
 void shm_update_progress(const int debuglvl, int semid, int *shm_progress, int set_percent);
 pid_t get_vuurmuur_pid(char *vuurmuur_pidfile_location, int *shmid);
 int create_tempfile(const int, char *);
@@ -1417,6 +1424,7 @@ int config_check_logdir(const int debuglvl, const char *logdir);
 int config_check_vuurmuurdir(const int debuglvl, const char *logdir);
 int check_iptables_command(const int, struct vuurmuur_config *, char *, char);
 int check_iptablesrestore_command(const int, struct vuurmuur_config *, char *, char);
+int check_tc_command(const int, struct vuurmuur_config *, char *, char);
 int init_config(const int, struct vuurmuur_config *cnf);
 int reload_config(const int, struct vuurmuur_config *);
 int ask_configfile(const int debuglvl, char *question, char *answer_ptr, char *file_location, size_t size);
@@ -1514,6 +1522,15 @@ void VR_filter_cleanup(const int debuglvl, VR_filter *filter);
 char * VrGetString( char *fmt, ... );
 char * VrGetLenString(size_t max, char *fmt, ...);
 
+/*
+ * shape.c
+ */
+int libvuurmuur_is_shape_rule(const int, /*@null@*/struct options *);
+int libvuurmuur_is_shape_incoming_rule(const int, /*@null@*/struct options *);
+int libvuurmuur_is_shape_outgoing_rule(const int, /*@null@*/struct options *);
+int libvuurmuur_is_shape_interface(const int, /*@null@*/InterfaceData *);
+
+
 /*
     global vars
 */
